===============================
kiek
===============================

.. image:: https://img.shields.io/pypi/v/kiek.svg
        :target: https://pypi.python.org/pypi/kiek
        :alt: PyPi

.. image:: https://img.shields.io/travis/maartenq/kiek.svg
        :target: https://travis-ci.org/maartenq/kiek
        :alt: Travis CI

.. image:: https://codecov.io/gh/maartenq/kiek /branch/master/graph/badge.svg
        :target: https://codecov.io/gh/maartenq/kiek
        :alt: Coverage

.. image:: https://readthedocs.org/projects/kiek/badge/?version=latest
        :target: https://kiek.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/maartenq/kiek/shield.svg
        :target: https://pyup.io/repos/github/maartenq/kiek/
        :alt: Updates

.. image:: https://pyup.io/repos/github/maartenq/kiek/python-3-shield.svg
        :target: https://pyup.io/repos/github/maartenq/kiek/
        :alt: Python 3


A KISS Kiekshow App


* Free software: ISC license
* Documentation: https://kiek.readthedocs.io
* PyPi: https://pypi.python.org/pypi/kiek
* Travis CI: https://travis-ci.org/maartenq/kiek
* Codecov: https://codecov.io/github/maartenq/kiek
* PyUp: https://pyup.io/repos/github/maartenq/kiek/


Features
--------

* TODO


Credits
---------

This package was created with Cookiecutter_ and the `maartenq/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`maartenq/cookiecutter-pypackage`: https://github.com/maartenq/cookiecutter-pypackage

